"use strict";

const { images_url } = require("../../../../constants");

const SKILL_THEMES = [
    "Applications web",
    "Service backend, serveur, API REST, bases de données",
    "Sites web statiques, serveurs de fichiers",
    "Développement frontend, interfaces",
    "Conception et design UX / UI",
    "Création graphique bitmap et vectoriel",
    "Prototypes embarqués, IoT, Arduino",
    "Développement logiciel",
    "Applications Android",
];

const SKILL_STACK = [
    ["Javascript", "js.png"],
    ["Node.js", "node.png"],
    ["React.js", "react.png"],
    ["Python", "python.png"],
    ["C/C++", "c.png"],
    ["Rust", "rust.png"],
    ["MySQL", "mysql.png"],
    ["PostgreSQL", "postgre.png"],
    ["MongoDB", "mongodb.png"],
    ["HTML", "html.png"],
    ["CSS", "css.png"],
    ["Sass", "sass.png"],
    ["Docker", "docker.png"],
    ["Linux", "linux.png"],
    ["Nginx", "nginx.png"],
    ["Apache", "apache.png"],
];

class ServiceSection {
    render() {
        return {
            tag: "section",
            class: "page-contents-center",
            id: "service-section",
            typeof: "Service",
            additionalType: "Organization",
            contents: [
                {
                    tag: "h3",
                    contents:
                        "<blue>Nos compétences</blue> pour votre besoin <blue>numérique</blue>",
                    property: "slogan",
                },
                {
                    tag: "p",
                    property: "description",
                    contents: `
                    La demande numérique est omniprésente et de nombreuses entreprises ont besoin de bénéficier d'outils spécifiques réalisés sur mesure,
                    applications web et mobiles, site statiques, logiciels, ERP, etc, mais n'ont pas forcément les compétences chez elles, 
                    et n'ont pas non plus un besoin suffisamment grand pour embaucher une équipe de développement.
                    <br /><br />
                    <b><blue>Kuadrado</blue></b> propose de répondre à ce cas de figure pour les entreprises et organisations locales 
                    (Ardèche, Drôme, Rhône, Loire, Haute-Loire...) en étant leur <b>partenaire en développement <blue>web et logiciel</blue></b>.`,
                },
                {
                    tag: "p",
                    class: "teaser",
                    contents: [
                        {
                            tag: "strong",
                            property: "slogan",
                            contents:
                                "Des solutions <blue>sur mesure, légères, simples, maintenables, scalables et écologiques</blue>",
                        },
                    ],
                },
                {
                    tag: "div",
                    class: "skills",
                    contents: [
                        {
                            tag: "ul",
                            class: "skill-themes",
                            contents: SKILL_THEMES.map(item => {
                                return { tag: "li", contents: item, property: "about" };
                            }),
                        },
                        {
                            tag: "ul",
                            class: "skill-stack",
                            contents: SKILL_STACK.map(item => {
                                const [title, img] = item;
                                return {
                                    tag: "li",
                                    property: "about",
                                    contents: [
                                        {
                                            tag: "strong",
                                            contents: title,
                                        },
                                        {
                                            tag: "img",
                                            src: `${images_url}tech_logos/${img}`,
                                        },
                                    ],
                                };
                            }),
                        },
                        {
                            tag: "div",
                            class: "call-us",
                            contents: [
                                {
                                    tag: "h3",
                                    contents: `Un <blue>projet à réaliser</blue> ?
                                    <br/>Besoin d'informations, de conseils ou d'un <blue>devis</blue> ?`,
                                },
                                {
                                    tag: "a",
                                    href: "mailto:contact@kuadrado-software.fr",
                                    contents: "contact@kuadrado-software.fr",
                                    property: "email",
                                },
                                {
                                    tag: "a",
                                    href: "tel:+33475780872",
                                    contents: "04 75 78 08 72",
                                    property: "telephone",
                                },
                            ],
                        },
                    ],
                },
            ],
        };
    }
}

module.exports = ServiceSection;
